@@ -147,7 +147,8 @@ class TestTimestreamLoader_UnitTests:
                 'notshared': 'not_shared_dimension'
             }],
             capture_time=datetime(2021, 1, 1, 0, 0, 0, 0, pytz.UTC),
-            source=expected_source
+            source=expected_source,
+            is_multi=False
         )
         assert type(result) == TimestreamLoadResult
         assert len(result.accepted_records) == 2
@@ -197,7 +198,8 @@ class TestTimestreamLoader_UnitTests:
                 'time': int(expected_capture_time)
             }],
             capture_time=datetime(2021, 1, 1, 0, 0, 0, 0, pytz.UTC),
-            upsert=True
+            upsert=True,
+            is_multi=False
         )
         assert type(result) == TimestreamLoadResult
         assert len(result.accepted_records) == 1
@@ -244,7 +246,8 @@ class TestTimestreamLoader_UnitTests:
                 'time': int(expected_capture_time)
             }],
             capture_time=datetime(2021, 1, 1, 0, 0, 0, 0, pytz.UTC),
-            upsert=True
+            upsert=True,
+            is_multi=False
         )
         assert type(result) == TimestreamLoadResult
         assert len(result.accepted_records) == 1
@@ -363,7 +366,8 @@ class TestTimestreamLoader_UnitTests:
         accepted_records, rejected_records = loader._TimestreamLoader__write_upsert_records(
             common_dimensions=TimestreamDimensions(),
             records=[expected_valid_record, expected_invalid_record],
-            source=expected_source
+            source=expected_source,
+            is_multi=False
         )
         assert len(accepted_records) == 1
         assert accepted_records[0] == expected_valid_record
