@@ -64,13 +64,14 @@ class TimestreamLoader(TimestreamReader):
         self,
         data: list,
         capture_time: datetime,
+        database_name: str = None,
+        table_name: str = None,
         source: str = None,
         upsert: bool = False,
         ignore_parse_error: bool = True,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
         min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
-        is_multi: bool = False
-
+        is_multi: bool = True
     ) -> dict:
         '''
         Performs a Timestream load. Validates the input and parses the data into Timestream records.
@@ -79,6 +80,8 @@ class TimestreamLoader(TimestreamReader):
         return self.__load(
             data,
             capture_time,
+            database_name,
+            table_name,
             source,
             upsert,
             ignore_parse_error,
@@ -92,12 +95,14 @@ class TimestreamLoader(TimestreamReader):
         self,
         data: list,
         capture_time: datetime,
+        database_name: str = None,
+        table_name: str = None,
         source: str = None,
         upsert: bool = False,
         ignore_parse_error: bool = True,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
         min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
-        is_multi: bool = False
+        is_multi: bool = True
     ) -> dict:
         '''
         Performs a dry run of a Timestream load, including validating the input values and parsing data
@@ -107,6 +112,8 @@ class TimestreamLoader(TimestreamReader):
         return self.__load(
             data,
             capture_time,
+            database_name,
+            table_name,
             source,
             upsert,
             ignore_parse_error,
@@ -120,13 +127,15 @@ class TimestreamLoader(TimestreamReader):
         self,
         data: list,
         capture_time: datetime,
+        database_name: str = None,
+        table_name: str = None,
         source: str = None,
         upsert: bool = False,
         ignore_parse_error: bool = True,
         preview: bool = False,
         max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
         min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
-        is_multi: bool = False
+        is_multi: bool = True
     ) -> TimestreamLoadResult:
         self._logger.info(f'Loading data with {len(data)} elements')
 
@@ -157,9 +166,24 @@ class TimestreamLoader(TimestreamReader):
             if source:
                 dimensions.add_dimension('source', source, overwrite=True)
             if b.records and upsert:
-                accepted_records, rejected_records = self.__write_upsert_records(dimensions, b.records, source, is_multi)
+                accepted_records, rejected_records = self.__write_upsert_records(
+                    dimensions,
+                    b.records,
+                    source,
+                    database_name,
+                    table_name,
+                    is_multi
+                )
             elif b.records:
-                accepted_records, rejected_records = self.__write_insert_records(dimensions, b.records, source, capture_time, is_multi)
+                accepted_records, rejected_records = self.__write_insert_records(
+                    dimensions,
+                    b.records,
+                    source,
+                    capture_time,
+                    database_name,
+                    table_name,
+                    is_multi
+                )
 
             if accepted_records:
                 result.add_accepted_records(accepted_records)
@@ -174,7 +198,9 @@ class TimestreamLoader(TimestreamReader):
         records: List[TimestreamRecord],
         source: str,
         capture_time: datetime,
-        is_multi: bool
+        database_name: str = None,
+        table_name: str = None,
+        is_multi: bool = True
     ) -> tuple:
         self._logger.debug(f'Writing insert records with {len(records)} records')
         assert capture_time, 'A capture time needs to be provided'
@@ -198,8 +224,8 @@ class TimestreamLoader(TimestreamReader):
                 common_att['Dimensions'] = common_dimensions.loadable()
 
             _ = self._timestream_write_client.write_records(
-                DatabaseName=self.__database_name,
-                TableName=self.__table_name,
+                DatabaseName=database_name or self.__database_name,
+                TableName=table_name or self.__table_name,
                 CommonAttributes=common_att,
                 Records=[
                     r.loadable(omit_dimensions=common_dimensions)
@@ -216,7 +242,9 @@ class TimestreamLoader(TimestreamReader):
         common_dimensions: TimestreamDimensions,
         records: List[TimestreamRecord],
         source: str,
-        is_multi: bool = False
+        database_name: str = None,
+        table_name: str = None,
+        is_multi: bool = True
     ) -> tuple:
         self._logger.debug(f'Writing upsert records with {len(records)} records')
         accepted_records, rejected_records = records, []
@@ -237,8 +265,8 @@ class TimestreamLoader(TimestreamReader):
                 common_att['Dimensions'] = common_dimensions.loadable()
                     
             _ = self._timestream_write_client.write_records(
-                DatabaseName=self.__database_name,
-                TableName=self.__table_name,
+                DatabaseName=database_name or self.__database_name,
+                TableName=table_name or self.__table_name,
                 CommonAttributes=common_att,
                 Records=[
                     r.loadable(omit_dimensions=common_dimensions)
